@@ -53,3 +53,5 @@ rgl.enum (magfiltertype, nearest=0, linear=1)
 rgl.enum.gl2ps <- function (postscripttype)
 rgl.enum (postscripttype, ps=0, eps=1, tex=2, pdf=3, svg=4, pgf=5)
 
+rgl.enum.pixelcomponent <- function(component)
+rgl.enum(component, red=0, green=1, blue=2, alpha=3, depth=4, luminance=5)
